/**
 * @file departure_step.h
 * @author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * @brief 
 * @version 0.1
 * @date 2024-08-30
 * 
 * @copyright Copyright (c) 2024
 * 
 */

#ifndef CREATE_MISSION_XML_SRC_LIBS_MISSION_STEPS_DEPARTURE_STEP_H_
#define CREATE_MISSION_XML_SRC_LIBS_MISSION_STEPS_DEPARTURE_STEP_H_

#include <string>
#include <aixml/endnode.h>

/** \brief Class for flight steps on departure
 */
class departure_step {
 public:
    /* Constructor and destructor */
    /** \brief Constructor for class departure_step
     * \param a_mode: flight mode of the departure step
     * \param a_rating: rating of the departure step
     * \param a_derate: derate of the departure step [-]
     * \param a_config: configuration of the departure step
     * \param an_end_altitude: altitude at the end of the departure step [m]
     * \param a_rate_of_climb_limit: rate of climb of the departure step [m/s]
     * \param an_end_CAS: calibrated airspeed at the end of the departure step [m/s]
     */
    departure_step(const std::string &a_mode, const std::string &a_rating, double a_derate,
                    const std::string &a_config, double an_end_altitude, double a_rate_of_climb_limit, double an_end_CAS);
    /** \brief Destructor for class departure_step
     */
    virtual ~departure_step();

    /** \brief function to write departure steps into mission file
     * \details It checks the given values and updates the endnodes within mission_file
     * \param subpath: path where the endnode shall write data
     * \param mission_file: xml node of the given mission file
     */
    void write_departure_steps(std::string subpath, node* mission_file);

 private:
    /* Attributes */
    Endnode<std::string> mode; /* Mode during this step */
    Endnode<std::string> rating; /**< Rating of the departure step */
    Endnode<double> derate; /**< Derate of the departure step [-] */
    Endnode<std::string> configuration; /**< Configuration of the departure step */
    Endnode<double> rate_of_climb_limit; /**< Rate of climb of the departure step [fpm] */
    Endnode<double> end_CAS; /**< Calibrated air speed at the end of the departure step [m/s] */
    Endnode<double> end_altitude; /**< Flight altitude at the end of the departure step [m] */
};

#endif // CREATE_MISSION_XML_SRC_LIBS_MISSION_STEPS_DEPARTURE_STEP_H_
