/**
 * \file missionConfig.h
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief configuration class for reading mission data from conf.xml
 * \version 0.1
 * \date 2023-12-04
 *
 * @copyright Copyright (c) 2023
 *
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_

#include <string>
#include <unordered_map>
#include <utility>
#include <vector>
#include <array>
#include <standardFiles/settings.h>
#include <aixml/endnode.h>
#include "../../emissionsClass.h"

/** \class MissionConfig
 * \brief Class for the config settings needed for mission calculation
*/
class MissionConfig {
 public:
    std::string keroseneMethodHC;/**<HC Emission index calculation method for kerosene; DLR Omega: mode_0, BFM2: mode_1, ICAO Emission indices: mode_2 */
    std::string kersoseneMethodCO;/**<CO Emission index calculation method for kerosene; DLR Omega: mode_0, BFM2: mode_1, ICAO Emission indices: mode_2 */
    std::string keroseneMethodNOx;/**<NOx Emission index calculation method for kerosene; P3T3: mode_0, BFM2: mode_1, GasTurb: mode_2 */
    std::string keroseneMethodSoot;/**<soot Emission index calculation method for kerosene; DLR correlation: mode_0, Whyte: mode_1, constant: mode_2 */
    std::string hydrogenMethodNOx; /**<NOx Emission index calculation method for hydrogen; P3T3: mode_0*/
    double relativeHumidity;/**< Relative humidity of air [-] */

    /** \brief Default constructor of class missionConfig
     */
    MissionConfig();


    /** \brief Destructor of class missionConfig
     */
    virtual ~MissionConfig();

    /** \brief Function to read mission specific data from ecological_assessment_config.xml
     * \param config Node of the data structure defined by config file
     */
    void readAllConfigData(const node& config);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_
