/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.  // NOLINT
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONIODATA_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONIODATA_H_

#include <string>
#include <unordered_map>
#include <utility>
#include <vector>
#include <array>
#include <memory>

#include <moduleBasics/runtimeIO.h>
#include <standardFiles/settings.h>
#include <engine/engine.h>
#include "missionConfig.h"
#include "mission.h"

class Mission;

/** \class MissionIOData
 * \brief Class for the settings that are needed in the mission calculation
 */
class MissionIOData {
 public:
    MissionConfig config; /**< Object of class missionConfig which contains data from configuration file*/
    Engine myEngine; /**< Object of class engine that contains engine data */
    int flightsPerYear;/**< Number of flights per year [-]*/
    int numberOfEngines; /**< Number of engines [-] */
    int durationOperation; /**< Years of aircraft operation [a] */

    /** \brief Construct a new missionIOData object     *
     * \param rtIO Access to runtime IO
     */
    explicit MissionIOData(std::shared_ptr<RuntimeIO> rtIO);

    /** \brief Destructor of class missionIOData
     */
    virtual ~MissionIOData() {}

    /** \brief Function writes emissions of one study mission into aircraft xml
     * \param ecologicalAssessmentXML Pointer to ecological values
     * \param thisMission Access mission object data
     */
    void updateEcologicalAssessmentXml(std::shared_ptr<node> ecologicalAssessmentXML, const Mission& thisMission);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONIODATA_H_
