/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.  // NOLINT
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQISCHAEFERIODATA_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQISCHAEFERIODATA_H_

#include <string>
#include <vector>
#include <memory>
#include <moduleBasics/runtimeIO.h>
#include <engine/engine.h>
#include <standardFiles/settings.h>
#include <aixml/node.h>

/** \class  AQISchaeferIOData
 * \brief Data class for air qualitiy index calculation according to Schaefer
 */
class AQISchaeferIOData {
 public:
    /* Input parameter*/
    Engine myEngine; /**< Engine object */
    double numberOfEngines; /**< Number of engines [-]*/
    double CO_LTO; /**< CO emissions mass of study mission LTO[kg]*/
    double HC_LTO; /**< HC emissions mass of study mission LTO[kg]*/
    double NOx_LTO; /**< NOx emissions mass of study mission LTO [kg]*/
    double c_soot_LTO_max;/**< Maximum soot concentration during Landing and Takeoff of study mission [mg/kg]*/

    /** \brief construct a new schaefer IO data object
     * \param rtIO Access to runtime IO
     * \param ecoAssXML Node of ecological assessment results xml
     */
    explicit AQISchaeferIOData(std::shared_ptr<RuntimeIO> rtIO, std::shared_ptr<node> ecoAssXML);

    /** \brief Destructor of class SchaeferIOData
     */
    virtual ~AQISchaeferIOData() {}

    /** \brief Funtions reads data from ecological asessment results xml
     * \param ecoAssXML Node of eco xml
     */
    void readEcologicalAssessmentXML(const node& ecoAssXML);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQISCHAEFERIODATA_H_
