/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.  // NOLINT
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARAIODATA_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARAIODATA_H_

#include <string>
#include <vector>
#include <memory>
#include <moduleBasics/runtimeIO.h>
#include <standardFiles/settings.h>
#include <aixml/node.h>
#include "dallaraConfig.h"


// TODO(franz#1#): T126 check if sum of components = 100%
/** \class  DallaraIOData
 * \brief Global class for the program settings that are accessed throughout the program.
 */
class DallaraIOData {
 public:
    DallaraConfig configuration; /**< Data from configuration file*/
    /* Input parameter*/
    double rangeStudy; /**< Range Study Mission [m] */
    double topOfClimbRange; /**< Climb range of study mission [m]*/
    double topOfDescentRange; /**< Cruise range of study mission [m]*/
    int flightsPerYear;/**< Number of flights per year [-]*/
    int durationOperation;/**< Years of aircraft operation [a]*/
    double emissionMass[8]{0., 0., 0., 0., 0., 0., 0., 0.};/**< Emissions emitted during one mission [kg] or mission range for aviation cloudiness produced during mission*/
    std::vector<double> endOfCruiseStep; /**< Cruise step length relative to mission length [-]*/
    std::vector<double> flightLevel; /**< Flight level of cruise step*/
    /* Output parameter*/
    double ATR; /**< Average temperature response: Integrated temperature change per year caused by aircraft operation divided by operating lifetime [K]*/

    /** \brief construct a new schaefer IO data object
     * \param acXML Node of aircraft xml
     * \param config Node of configuration xml
     * \param ecoAssXML Node of ecological assessment results xml
     */
    explicit DallaraIOData(const node& acXML, const node& config, std::shared_ptr<node> ecoAssXML);

    /** \brief Destructor of class SchaeferIOData
     */
    virtual ~DallaraIOData() {}

    /** \brief Funtions reads data from aircraft xml
     * \param acXML Node of aircraft xml
     */
    void readAircraft(const node& acXML);

    /** \brief Funtions reads data from ecological asessment results xml
     * \param ecoAssXML Node of eco xml
     */
    void readEcologicalAssessmentXML(const node& ecoAssXML);


    /** \brief Funtions updates data from aircraft
     * \param rtIO Access to runtime IO
     */
    void updateAircraftXML(std::shared_ptr<RuntimeIO> rtIO);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARAIODATA_H_
