/**
 * \file empennageDesign.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief base module for empennage design
 * \version 0.1
 * \date 2023-10-11
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "empennageDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>
#include <format>

#include "bwb/vertical_tails/low/LowVerticalTailsBwb.h"
#include "taw/conventional/low/lowConventionalEmpennageDesign.h"

EmpennageDesign::EmpennageDesign(const int argc, char *argv[], const std::string &toolName,
                                 const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string usedtype = EndnodeReadOnly<std::string>("requirements_and_specifications/design_specification/configuration/empennage_definition/empennage_type").read(rtIO_->acxml).value();
  std::string fidelity = EndnodeReadOnly<std::string>("program_settings/fidelity_selection").read(rtIO_->moduleConfig).value();
  route = {configuration, usedtype, fidelity};
  strategy.setStrategy(design_routing(route)(rtIO_));
}

strategyaccess EmpennageDesign::design_routing(const std::vector<std::string> &route) {
  /* Routing table */
  std::map<std::string, std::map<std::string, std::map<std::string, strategyaccess>>> table = {
      {"tube_and_wing",
       std::map<std::string, std::map<std::string, strategyaccess>>{
           {"conventional",
            std::map<std::string, strategyaccess>{
                {"low",
                 [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<taw::low::Conventional>(arg); }},
            }},
       }},
      {"blended_wing_body",
       std::map<std::string, std::map<std::string, strategyaccess>>{
           {"vertical_tails",
            std::map<std::string, strategyaccess>{
                {"low",
                 [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<bwb::low::VerticalTails>(arg); }},
            }}}}};

  return table[route.at(0)][route.at(1)][route.at(2)];
}
