/**
 * \file flops_mass_methods.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief
 * \version 0.1
 * \date 2023-11-23
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "flopsMassMethod.h"

#include <unitConversion/unitConversion.h>

#include <cmath>

namespace flops {

double fin_mass(int number_of_fins, double area, double taper_ratio, double design_gross_weight) {
  const double dg_lb = convertUnit(KILO, GRAM, NOPREFIX, POUND, design_gross_weight);
  const double area_sqft = convertUnit(AREA, NOPREFIX, METER, NOPREFIX, FOOT, area);
  const double mass = 0.32 * pow(dg_lb, 0.3) * (taper_ratio + 0.5) * area_sqft;
  return convertUnit(NOPREFIX, POUND, KILO, GRAM, mass);
}

double horizontal_stabilizer_mass(double area, double taper_ratio, double design_gross_weight) {
  const double dg_lb = convertUnit(KILO, GRAM, NOPREFIX, POUND, design_gross_weight);
  const double area_sqft = convertUnit(AREA, NOPREFIX, METER, NOPREFIX, FOOT, area);
  const double mass = 0.53 * pow(dg_lb, 0.2) * (taper_ratio + 0.5) * area_sqft;
  return convertUnit(NOPREFIX, POUND, KILO, GRAM, mass);
}

double vertical_stabilizer_mass(int number_of_tails, double area, double taper_ratio, double design_gross_weight) {
  const double dg_lb = convertUnit(KILO, GRAM, NOPREFIX, POUND, design_gross_weight);
  const double area_sqft = convertUnit(AREA, NOPREFIX, METER, NOPREFIX, FOOT, area);
  const double mass = 0.32 * pow(dg_lb, 0.3) * (taper_ratio + 0.5) * pow(number_of_tails, 0.7) * pow(area_sqft, 0.85);
  return convertUnit(NOPREFIX, POUND, KILO, GRAM, mass);
}
}  // namespace flops