def payload_tube_floor_thickness_calculation(payload_tube_wall_thickness, runtime_output):
    """ Calculates payload tube floor thicknesses from given payload tube wall thickness.
        References and calculation method:
            [1] Prof. Dr.-Ing. Juergen Thorbeck TU-Berlin (2006), Script "Flugzeugentwurf I und II" page: XYZ
                cabin_floor_thickness = 1.5 * wall_thickness [inch]

    :param dict payload_tube_wall_thickness: Dict containing all payload tube wall thicknesses from current project
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict payload_tube_floor_thickness: Dict containing all payload tube floor thicknesses.
    """
    ''' initialize local parameter '''
    payload_tube_floor_thickness = {}

    # Calculation of floor thickness according to [1].
    for payload_tube, cabin_wall_thickness in payload_tube_wall_thickness.items():
        payload_tube_floor_thickness[payload_tube] = round(1.5 * cabin_wall_thickness, 3)

    ''' debug print '''
    runtime_output.debug('Debug: The payload_tube_floor_thickness_calculation function was successfully executed!')

    return payload_tube_floor_thickness
