/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * \file awInitialSizingConfig.h
 * \author Sara Hijazi (hijazi@ifb.uni-stuttgart.de)
 * \brief initial sizing class for reading from initialSizing_conf.xml 
 * \version 0.1
 * \date 2024-02-28
 * 
 * @copyright Copyright (c) 2023
 * 
 */
#ifndef INITIALSIZING_SRC_TAW_TAWINITIALSIZINGCONFIG_H_
#define INITIALSIZING_SRC_TAW_TAWINITIALSIZINGCONFIG_H_

#include <string>
#include <vector>
#include <memory>
#include <moduleBasics/runtimeIO.h>  // NOLINT
#include "../toolinfo.h"

/* STANDARD SYSTEMS DESIGN CONFIG */
/**
 * \brief Storage class for non system specific values from configuration xml
 * 
 */
class TawInitialSizingConfig {
 public:
    explicit TawInitialSizingConfig(const node& config) {}
    bool designCase = true;/**< Determine whether system architecture is also sized **/
    double ff_warmup = 0.0;
    double ff_taxi = 0.0;
    double ff_takeoff = 0.0;
    double ff_climb = 0.0;
    double ff_descent = 0.0;
    double ff_missedandclimb = 0.0;
    double ff_land = 0.0;
    double SFCKerosene = 0.0;
    double LDInitialCruise = 0.0;
    double LDInitialLoiter = 0.0;
    int numberPassengersFC = 0.0;
    int numberPassengersBC = 0.0;
    int numberPassengersEC = 0.0;
    int numberOfPilots = 0.0;
    int numberOfEngines = 0.0;
    double Cfeq = 0.0;
    double CLmaxTO = 0.0;
    double DeltaCD_HL = 0.0;
    double AR = 0.0;
    double e = 0.0;
    double Deltagamma = 0.0;
    double CLmaxL = 0.0;
    double ml_mo = 0.0;
    double mcr_mo = 0.0;
    double optimalCL = 0.0;

    std::string theProgramName; /**< Name of intial sizing program depending on design or study case **/

    void readAll(const node& config) {
        readProgramSettings(config);
    }

 private:
    void readProgramSettings(const node& config);
};

#endif  // INITIALSIZING_SRC_TAW_TAWINITIALSIZINGCONFIG_H_
