/**
 * \file operating_conditions.cpp
 * \author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * \brief
 * \version 0.1
 * \date 2024-08-30
 *
 * @copyright Copyright (c) 2024
 *
 */

#include "operating_conditions.h"

#include "../mission_file_data_handler/mission_file_data_handler.h"

/* Initialization of attributes for the operating_conditions object with the constructor */
operating_conditions::operating_conditions(std::vector<mission_file_data_handler::mission_data_set>* mission_data)
    :
    mission_step(0),
    rating(""),
    derate(1.),
    CI(0.),
    config(""),
    bleed_times(),
    bleed_values(),
    shaft_power_times(),
    shaft_power_values(),
    background_bleed(0.),
    background_shaft_power(0.),
    mission_data(mission_data) {
}

/* Destructor of the operating_conditions object */
operating_conditions::~operating_conditions() {
}

void operating_conditions::set_segment_operating_conditions(const uint16_t &i) {
    this->mission_step = i;
    this->config = (*mission_data).at(i).config;
    this->rating = (*mission_data).at(i).rating;
    this->derate = (*mission_data).at(i).derate;
    this->CI = 0.;
    if ((*mission_data).at(i).bleed_schedule.size()) {
        for (unsigned int j(0); j < (*mission_data).at(i).bleed_schedule.size(); j++) {
            this->bleed_times.push_back((*mission_data).at(i).bleed_schedule.at(j).time);
            this->bleed_values.push_back((*mission_data).at(i).bleed_schedule.at(j).value);
        }
    }
    if ((*mission_data).at(i).shaft_power_schedule.size()) {
        for (unsigned int j(0); j < (*mission_data).at(i).shaft_power_schedule.size(); j++) {
            this->shaft_power_times.push_back((*mission_data).at(i).shaft_power_schedule.at(j).time);
            this->shaft_power_values.push_back((*mission_data).at(i).shaft_power_schedule.at(j).value);
        }
    }
    this->background_bleed = (*mission_data).at(i).background_bleed;
    this->background_shaft_power = (*mission_data).at(i).background_shaft_power;
}

void operating_conditions::delete_used_bleed_and_shaft_power_offtakes(const double& time_step) {
    if (!this->bleed_times.empty()) {
        double time_sum(0.);
        while (!this->bleed_times.empty() && time_sum < time_step) {
            if (this->bleed_times.front() > time_step) {
                this->bleed_times.front() -= time_step;
                break;
            } else {
                time_sum += this->bleed_times.front();
                this->bleed_times.erase(this->bleed_times.begin());
                this->bleed_values.erase(this->bleed_values.begin());
            }
        }
    }
    if (!this->shaft_power_times.empty()) {
        double time_sum(0.);
        while (!this->shaft_power_times.empty() && time_sum < time_step) {
            if (this->shaft_power_times.front() > time_step) {
                this->shaft_power_times.front() -= time_step;
                break;
            } else {
                time_sum += this->shaft_power_times.front();
                this->shaft_power_times.erase(this->shaft_power_times.begin());
                this->shaft_power_values.erase(this->shaft_power_values.begin());
            }
        }
    }
}
