/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_VNDIAGRAM_ABSTRACTVNDIAGRAM_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_VNDIAGRAM_ABSTRACTVNDIAGRAM_H_

#include <vector>

class abstractVnDiagram {
 public:
    virtual ~abstractVnDiagram() { }
    virtual void doVnDiagram() = 0;

    /**\class configDiagram class contains load factor limitations depending on the aircraft speed
    *
    */
    class configDiagram {
     public:
        double speed; /**< Aircraft speed (m/s) */
        double n_upperBound; /**< Maximum positive load factor n (-) */
        double n_lowerBound; /**< Minimum negative load factor n (-) */

        configDiagram()
            :
            speed(0.),
            n_upperBound(0.),
            n_lowerBound(0.) {
        }
    };

    vector<configDiagram> myCleanDiagram; /**< List of data for the v-N diagram for the clean configuration */
    vector<configDiagram> myLandingDiagram; /**< List of data for the v-N diagram for the landing configuration */
    vector<configDiagram> myTakeoffDiagram; /**< List of data for the v-N diagram for the Take-Off configuration */
};

#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_VNDIAGRAM_ABSTRACTVNDIAGRAM_H_

