/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_ABSTRACTLANDINGPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_ABSTRACTLANDINGPERFORMANCE_H_

#include <vector>

class abstractLandingPerformance {
 public:
    virtual ~abstractLandingPerformance() { }
    virtual void doLandingPerformance(double theRunwaySlope, double theGroundFrictionBraking, double theHeadWind) = 0;

    /**\class dataLND Class contains data about the landing
    *
    */
    class dataLDN {
     public:
        /** \brief Allowed landing distance with all engines operating and MLM
         *  \details landing distance required including 60% safety margin (EASA: 60 percent of maximum available runway length) (m)
         */
        double ALD_AEO;
        double grossMass; /**< Aircraft mass (kg) */

        dataLDN() {
            ALD_AEO = 0.0;
            grossMass = 0.0;
        }
    };

    /**\class dataElevationLDN Class contains landing parameters for different elevations
    *
    */
    class dataElevationLDN {
     public:
        double elevation; /**< Elevation (m) */
        std::vector<dataLDN> myLDN; /**< List of landing data (time, mass, landing distance) */

        dataElevationLDN() {
            elevation = 0.0;
        }
    };
    std::vector<dataElevationLDN> myLDNField; /**< List of elevation at landing data */

};

#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_ABSTRACTLANDINGPERFORMANCE_H_
