/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_performance_assessmentFactory_H_
#define performance_assessment_SRC_TAW_DEFUALTMETHODS_performance_assessmentFactory_H_

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>
#include <aixml/node.h>
#include <moduleBasics/report.h>

#include <functional>
#include <map>
#include <memory>
#include <string>

#include "performance_assessment_settings.h"
#include "../defaultMethods/aircraft.h"


/* Include custom implementation header files here */
// ...

/* Default methods and classes */
#include "fuelPlanning/low_fidelity/fuelPlanning.h"
#include "optimizeMissionProfile/low_fidelity/optimizeMissionProfile.h"
#include "payloadRange/low_fidelity/payloadRange.h"
#include "enginePerformance/low_fidelity/enginePerformance.h"
#include "SARPerformance/low_fidelity/SARPerformance.h"
#include "ceilingPerformance/low_fidelity/ceilingPerformance.h"
#include "takeOffPerformance/low_fidelity/takeOffperformance.h"
#include "landingPerformance/low_fidelity/landingPerformance.h"
#include "VnDiagram/low_fidelity/VnDiagram.h"

/* Interfaces */
#include "ceilingPerformance/abstractCeilingPerformance.h"
#include "fuelPlanning/abstractFuelPlanning.h"
#include "optimizeMissionProfile/abstractOptimizeMissionProfile.h"
#include "payloadRange/abstractPayloadRange.h"
#include "enginePerformance/abstractEnginePerformance.h"
#include "SARPerformance/abstractSARPerformance.h"
#include "flightEnvelopes/abstractFlightEnvelopes.h"
#include "takeOffperformance/abstractTakeOffPerformance.h"
#include "landingPerformance/abstractLandingPerformance.h"
#include "VnDiagram/abstractVnDiagram.h"

class performance_assessment_output;

namespace taw {

class performance_assessment_factory : public Strategy, std::enable_shared_from_this<performance_assessment_factory> {
 public:
    explicit performance_assessment_factory(const std::shared_ptr<RuntimeIO>& rtIOin);
    ~performance_assessment_factory() = default;

    void initialize();
    void run();
    void update();
    void report();
    void save();

    const std::shared_ptr<RuntimeIO>& rtIO;
    performance_assessment_settings mySettings;
    std::shared_ptr<performance_assessment_settings> mySettingsPt;
    aircraft myAcft;
    std::shared_ptr<aircraft> myAcftPt;
    node& missionXML;

    std::shared_ptr<abstractFuelPlanning> abstractFuelPlanningPt;
    std::shared_ptr<abstractFuelPlanning> theFuelPlanning;  /**< fuelPlanning object */
    std::shared_ptr<abstractOptimizeMissionProfile> abstractOptimizeMissionProfilePt;
    std::shared_ptr<abstractOptimizeMissionProfile> theOptimizeMission;  /**< optimizeMissionProfile object */
    std::shared_ptr<abstractPayloadRange> abstractPayloadRangePt;  /**< payloadRange object */
    std::shared_ptr<abstractEnginePerformance> abstractEnginePerformancePt;  /**< enginePerformance object */
    std::shared_ptr<abstractCeilingPerformance> abstractCeilingPerformancePt; /**< ceilingPerformance object*/
    std::shared_ptr<abstractFlightEnvelopes> abstractFlightEnvelopesPt; /**< flightEnvelopes object */
    std::shared_ptr<abstractSARPerformance> abstractSARPerformancePt; /**< SARPerformance object */
    std::shared_ptr<abstractTakeOffPerformance> abstractTakeOffPerformancePt; /**< takeOffPerformance object */
    std::shared_ptr<abstractLandingPerformance> theLandingPerformance; /**< landingPerformance object */
    std::shared_ptr<abstractVnDiagram> theVnDiagram; /**< VnDiagram object */

    std::string fidelityLevelFuelPlanning;
    std::string fidelityLevelOptimizeMission;
    std::string fidelityLevelPayloadRangeDiagram;
    std::string fidelityLevelEnginePerformance;
    std::string fidelityLevelFlightEnvelopePerformance;
    std::string fidelityLevelClimbPerformance;
    std::string fidelityLevelTakeOffPerformance;
    std::string fidelityLevelLandingPerformance;
    std::string fidelityLevelVnDiagram;
    std::string fidelityLevelSARPerformance;
    std::string fidelitylevelTakeOffPerformance;
};

}  // namespace taw
#endif   // CALCULATEPERFORMANCE_SRC_TAW_DEFUALTMETHODS_LOW_FIDELITY_performance_assessment_Factory_H_
