/*  Copyright (C) 2024 Chair of Aircraft Design, Technical University Munich
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file engine_design.cpp
 * @brief Implementation of the common engine design functions.
 * @author Sebastian Oberschwendtner (sebastian.oberschwendtner@tum.de)
 * @version 3.0.0
 * @date 2024-02-22
 */

/* === Includes === */
#include "engine_design.h"
#include <format>
#include "../io/engine_xml.h"
#include "../utility.h"

namespace design
{
    void EngineDesigner::write_deck_value(const DeckData &data) const
    {
        /* The deck values assume a ; as separator */
        constexpr char delimiter = ';';

        /* Get the file name to export to */
        const std::filesystem::path file_name = engine_directory_ / (data.name + ".csv");

        /* Open the file */
        std::ofstream file(file_name, std::ios::out | std::ios::trunc);

        /* Cache the Mach line */
        std::stringstream mach_line;
        std::for_each(data.Mach.begin(), data.Mach.end(), [&mach_line](const auto &mach)
                      { mach_line << mach << delimiter; });

        /* Insert the data lines in the file */
        for (size_t index_N = 0; index_N < data.N.size(); ++index_N)
        {
            /* Insert the N value and the cached Mach values */
            file << data.N.at(index_N) << delimiter << mach_line.str() << '\n';

            /* Insert the FL values and the data values */
            for (size_t index_FL = 0; index_FL < data.FL.size(); ++index_FL)
            {
                file << data.FL.at(index_FL) << delimiter;
                std::for_each(
                    data.values[index_N][index_FL].begin(),
                    data.values[index_N][index_FL].end(),
                    [&file](const auto &value)
                    {
                        file << value << delimiter;
                    });
                file << '\n';
            }
            file << '\n';
        }

        /* Close the file */
        file.close();
    }
}; // namespace design
