/*  Copyright (C) 2023 Chair of Aircraft Design, Technical University Munich
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file test_settings.cpp
 * @author Sebastian Oberschwendtner (sebastian.oberschwendtner@tum.de)
 * @brief Test the settings of the propulsion design module.
 * @version 3.0.0
 * @date 2023-12-22
 */

/* === Includes === */
#include <filesystem>
#include <gtest/gtest.h>

/* Unit Under Test */
#include "settings.h"

/* === Fixtures === */

/* === Tests === */
/**
 * @brief Test the technology factors of the settings.
 */
TEST(Settings, TechnologyFactors)
{
    /* Create default settings */
    Settings settings{};

    /* Check the default technology factors */
    ASSERT_EQ(settings.technology_factor("engine_mass"), 1.0);
    ASSERT_EQ(settings.technology_factor("nacelle_mass"), 1.0);
    ASSERT_EQ(settings.technology_factor("pylon_mass"), 1.0);
    ASSERT_EQ(settings.technology_factor("engine_efficiency"), 1.0);

    /* Check accessing invalid factors */
    ASSERT_THROW(settings.technology_factor("invalid_factor"), std::out_of_range);
}
