/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef SYSTEMSDESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THEGEARBOXES_H_
#define SYSTEMSDESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THEGEARBOXES_H_

#include <string>

/** \brief contains all properties of the gear boxes
 */
class theGearboxes {
 public:
    double Mass;/**<[kg] gear box mass*/
    double efficiencyFactor;/**<efficiency factor of the gearbox*/

    /** \brief calculates the gearbox mass
     *
     * \param deviceType string: type of the device
     * \param theMTOM double: [kg] maximum takeoff mass
     * \param wingSref double: [m^2] reference wing area
     * \return void
     *
     */
    void getMass(const std::string& deviceType, double theMTOM, double wingSref);

    explicit theGearboxes(const std::string& Type);
    virtual ~theGearboxes();
};

#endif // SYSTEMSDESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THEGEARBOXES_H_
