/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file systemsDesign.cpp
 * @author Ellen Seabrooke (seabrooke@ifb.uni-stuttgart.de)
 * @brief Base module for systems design
 * @version 0.1
 * @date 2023-07-24
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <map>


#include <moduleBasics/strategySelector.h>
#include "systemsDesign.h"
#include "standardSystemsDesign.h"

namespace fs = std::filesystem;

systemsDesign::systemsDesign(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion) : Module(argc, argv, toolName, toolVersion) {
    /* at the moment systemsDesign only offers the STANDARD route */
    rtIO_ = get_RuntimeIO();
    std::string method = rtIO_->moduleConfig.at("program_settings/modes/value");
    route_ = {method};
    strategy_.setStrategy(routing_(route_)(rtIO_));
}

strategyaccess systemsDesign::routing_(const std::vector<std::string>& route) {
    /* Routing table with only one case */
    std::map<std::string, strategyaccess> table = {
        {"STANDARD", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<standardSystemsDesign>(arg);}},
    };
    return table[route.at(0)];
}
