#include "sparMethods.h"
/**
 * \file sparMethods.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Spar methods
 * \version 0.1
 * \date 2024-01-11
 *
 * @copyright Copyright (c) 2024
 *
 */

#include "sparMethods.h"

::geom2::MultisectionSurface<geom2::PolygonSection> spar(const std::string& name, double inner_chord_rel_pos_from,
                                                         double inner_chord_rel_pos_to, double inner_spanwise_rel_pos,
                                                         double outer_chord_rel_pos_from, double outer_chord_rel_pos_to,
                                                         double outer_spanwise_rel_pos) {
  geom2::MultisectionSurface<geom2::PolygonSection> spar_element;
  geom2::Polygon_2 inner_chord;
  inner_chord.push_back(geom2::Point_2(inner_chord_rel_pos_from, 0.0));
  inner_chord.push_back(geom2::Point_2(inner_chord_rel_pos_to, 0.0));

  geom2::Polygon_2 outer_chord;
  outer_chord.push_back(geom2::Point_2(outer_chord_rel_pos_from, 0.0));
  outer_chord.push_back(geom2::Point_2(outer_chord_rel_pos_to, 0.0));

  spar_element.sections.emplace_back(inner_chord);
  spar_element.sections.emplace_back(outer_chord);

  spar_element.sections.front().origin = geom2::Point_3(0.0, 0.0, inner_spanwise_rel_pos);
  spar_element.sections.back().origin = geom2::Point_3(0.0, 0.0, outer_spanwise_rel_pos);
  spar_element.name = name;

  return spar_element;
}

std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> user_defined::spars(std::vector<Spar> spar_elements) {
  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> output_spar_elements;
  for (auto item : spar_elements) {
    output_spar_elements.push_back(
        spar(item.name.value(), item.position.inner_position_chord_from.value(),
             item.position.inner_position_chord_to.value(), item.position.inner_position_spanwise.value(),
             item.position.outer_position_chord_from.value(), item.position.outer_position_chord_to.value(),
             item.position.outer_position_spanwise.value()));
  }
  return output_spar_elements;
}

std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> get_spars(modes spars_mode,
                                                                         std::vector<Spar> spar_elements) {
  std::map<std::string,
           std::tuple<std::string, std::function<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>(void)>>>
      spars_selector = {{"mode_0", {"user_defined", [=]() { return user_defined::spars(spar_elements); }}}};
  const auto [method, spars_method] = spars_selector[spars_mode];

  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> output_spars = spars_method();
  std::cout << "Spars [method]: " << method << "\n";
  std::cout << "Spars [values]: "
            << "\n";
  std::cout << "\tNumber " << output_spars.size() << " [1]\n";

  return output_spars;
}