/**
 * \file taperRatioMethods.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Taper ratio methods
 * \version 0.1
 * \date 2023-12-12
 *
 * @copyright Copyright (c) 2023
 *
 */
#include "taperRatioMethods.h"

#include <functional>
#include <iostream>
#include <map>

double user_defined::taper_ratio(const double user_taper_ratio) { return user_taper_ratio; }

double howe::taper_ratio(const double aspect_ratio, const double quarter_chord_sweep) {
  return .2 * pow(aspect_ratio, 0.25) * pow(cos(quarter_chord_sweep), 2.0);
}

double get_design_taper_ratio(modes taper_ratio_mode, const double user_taper_ratio, const double aspect_ratio,
                              const double quarter_chord_sweep) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> taper_ratio_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::taper_ratio(user_taper_ratio); }}},
      {"mode_1", {"howe", [=]() { return howe::taper_ratio(aspect_ratio, quarter_chord_sweep); }}}};
  const auto [method, taper_ratio_method] = taper_ratio_selection[taper_ratio_mode];
  double taper_ratio = taper_ratio_method();
  std::cout << "Wing taper ratio [method]: " << method << "\n";
  std::cout << "Wing taper ratio  [value]: " << taper_ratio << " [1]\n";
  return taper_ratio;
}