/**
 * \file wingDesign.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Base module of wing desing
 * \version 0.1
 * \date 2023-12-05
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "wingDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>

#include "cantileverWingDesignTaw.h"
#include "lib/design_methods/cantileverLow.h"
#include "lowWingDesignBwb.h"

WingDesign::WingDesign(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string wing_type = "cantilever";
  route = {configuration, wing_type};
  strategy.setStrategy(design_route(route)(rtIO_));
}

strategyaccess WingDesign::design_route(const std::vector<std::string> &route) {
  std::map<std::string, std::map<std::string, strategyaccess>> table = {
      {"tube_and_wing",
       std::map<std::string, strategyaccess>{
           {"cantilever",
            [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<taw::cantilever::Wing>(arg); }},
       }},
      {"blended_wing_body",
       std::map<std::string, strategyaccess>{
           {"cantilever", [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<bwb::low::Wing>(arg); }},
       }}};
  return table[route.at(0)][route.at(1)];
}
